@@ -62,11 +62,13 @@ import logging
 import random
 import time
 
+import requests.exceptions
 import six
 
 from google.api_core import datetime_helpers
 from google.api_core import exceptions
 from google.api_core import general_helpers
+from google.auth import exceptions as auth_exceptions
 
 _LOGGER = logging.getLogger(__name__)
 _DEFAULT_INITIAL_DELAY = 1.0  # seconds
@@ -101,6 +103,8 @@ if_transient_error = if_exception_type(
     exceptions.InternalServerError,
     exceptions.TooManyRequests,
     exceptions.ServiceUnavailable,
+    requests.exceptions.ConnectionError,
+    auth_exceptions.TransportError,
 )
 """A predicate that checks if an exception is a transient API error.
 
@@ -230,9 +234,9 @@ class Retry(object):
     Args:
         predicate (Callable[Exception]): A callable that should return ``True``
             if the given exception is retryable.
-        initial (float): The minimum a,out of time to delay in seconds. This
+        initial (float): The minimum amount of time to delay in seconds. This
             must be greater than 0.
-        maximum (float): The maximum amout of time to delay in seconds.
+        maximum (float): The maximum amount of time to delay in seconds.
         multiplier (float): The multiplier applied to the delay.
         deadline (float): How long to keep retrying in seconds. The last sleep
             period is shortened as necessary, so that the last retry runs at
@@ -345,7 +349,7 @@ class Retry(object):
             predicate=self._predicate,
             initial=initial if initial is not None else self._initial,
             maximum=maximum if maximum is not None else self._maximum,
-            multiplier=multiplier if maximum is not None else self._multiplier,
+            multiplier=multiplier if multiplier is not None else self._multiplier,
             deadline=self._deadline,
             on_error=self._on_error,
         )
